@@ -1,40 +1,36 @@
 /*
- * $Id: nemesis-dns.h,v 1.1.1.1 2003/10/31 21:29:36 jnathan Exp $
- *
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <mark@stateful.net>
  * Copyright (C) 2001 - 2003 Jeff Nathan <jeff@snort.org>
  *
  * nemesis-dns.h (DNS Packet Injector)
- *
  */
 
-#ifndef __NEMESIS_DNS_H__
-#define __NEMESIS_DNS_H__
+#ifndef NEMESIS_DNS_H_
+#define NEMESIS_DNS_H_
 
 #if defined(HAVE_CONFIG_H)
-    #include "config.h"
+#include "config.h"
 #endif
 
 #include <stdio.h>
-#include <strings.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <strings.h>
 #include <sys/types.h>
+#include <unistd.h>
 #if defined(WIN32)
-    #include <pcap.h>
+#include <pcap.h>
 #endif
 #if defined(HAVE_NETINET_IN_H)
-    #include <netinet/in.h>
+#include <netinet/in.h>
 #elif defined(WIN32)
-    #include <winsock2.h>
+#include <winsock2.h>
 #endif
-#include <libnet.h>
 #include "nemesis.h"
+#include <libnet.h>
 
-int state;  /* default to UDP */
+extern int dns_state; /* default to UDP */
 
-int builddns(ETHERhdr *, IPhdr *, TCPhdr *, UDPhdr *, DNShdr *, FileData *,
-        FileData *, FileData *, char *);
+int builddns(ETHERhdr *, IPhdr *, TCPhdr *, UDPhdr *, DNShdr *, struct file *, struct file *, struct file *, libnet_t *);
 
-#endif /* __NEMESIS_DNS_H__ */
+#endif /* NEMESIS_DNS_H_ */
