@@ -1,38 +1,34 @@
 /*
- * $Id: nemesis-tcp.h,v 1.1.1.1 2003/10/31 21:29:37 jnathan Exp $
- *
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <mark@stateful.net>
  * Copyright (C) 2001 - 2003 Jeff Nathan <jeff@snort.org>
  *
  * nemesis-tcp.h (TCP Packet Injector)
- *
  */
 
-#ifndef __NEMESIS_TCP_H__
-#define __NEMESIS_TCP_H__
+#ifndef NEMESIS_TCP_H_
+#define NEMESIS_TCP_H_
 
 #ifdef HAVE_CONFIG_H
-    #include "config.h"
+#include "config.h"
 #endif
 
 #include <stdio.h>
-#include <strings.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <strings.h>
 #include <sys/types.h>
+#include <unistd.h>
 #if defined(WIN32)
-    #include <pcap.h>
+#include <pcap.h>
 #endif
 #if defined(HAVE_NETINET_IN_H)
-    #include <netinet/in.h>
+#include <netinet/in.h>
 #elif defined(WIN32)
-    #include <winsock2.h>
+#include <winsock2.h>
 #endif
-#include <libnet.h>
 #include "nemesis.h"
+#include <libnet.h>
 
-int buildtcp(ETHERhdr *, IPhdr *, TCPhdr *, FileData *, FileData *,
-        FileData *, char *);
+int buildtcp(ETHERhdr *, IPhdr *, TCPhdr *, struct file *, struct file *, struct file *, libnet_t *);
 
-#endif /* __NEMESIS_TCP_H__ */
+#endif /* NEMESIS_TCP_H_ */
