@@ -1,38 +1,34 @@
 /*
- * $Id: nemesis-udp.h,v 1.1.1.1 2003/10/31 21:29:38 jnathan Exp $
- *
  * THE NEMESIS PROJECT
  * Copyright (C) 1999, 2000, 2001 Mark Grimes <mark@stateful.net>
  * Copyright (C) 2001 - 2003 Jeff Nathan <jeff@snort.org>
  *
  * nemesis-udp.h (UDP Packet Injector)
- *
  */
 
-#ifndef __NEMESIS_UDP_H__
-#define __NEMESIS_UDP_H__
+#ifndef NEMESIS_UDP_H_
+#define NEMESIS_UDP_H_
 
 #if defined(HAVE_CONFIG_H)
-    #include "config.h"
+#include "config.h"
 #endif
 
 #include <stdio.h>
-#include <strings.h>
 #include <stdlib.h>
-#include <unistd.h>
+#include <strings.h>
 #include <sys/types.h>
+#include <unistd.h>
 #if defined(WIN32)
-    #include <pcap.h>
+#include <pcap.h>
 #endif
 #if defined(HAVE_NETINET_IN_H)
-    #include <netinet/in.h>
+#include <netinet/in.h>
 #elif defined(WIN32)
-    #include <winsock2.h>
+#include <winsock2.h>
 #endif
-#include <libnet.h>
 #include "nemesis.h"
+#include <libnet.h>
 
-int buildudp(ETHERhdr *, IPhdr *, UDPhdr *, FileData *, FileData *,
-        char *);
+int buildudp(ETHERhdr *, IPhdr *, UDPhdr *, struct file *, struct file *, libnet_t *);
 
-#endif /* __NEMESIS_UDP_H__ */
+#endif /* NEMESIS_UDP_H_ */
